==> open-xchange-realtime-core_7.4.0.orig.tar.bz2: open-xchange-realtime-core-7.4.0/com.openexchange.realtime/src/com/openexchange/realtime/exception/Transformer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.exception;

import java.io.Serializable;

/**
 * {@link Transformer} used to map RealtimException codes to codes that can be used for specific {@link Channel} implementations like
 * Atmosphere or Realtime.
 * 
 * @author <a href="mailto:martin.herfurth@open-xchange.com">Martin Herfurth</a>
 * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
 */
public class Transformer implements Serializable {

    private RealtimeExceptionCodes origin;
    private RealtimeExceptionCodes atmosphere;
    private RealtimeExceptionCodes xmpp;

    /**
     * Initializes a new {@link Transformer}.
     * 
     * @param origin The original ExceptionCode
     * @param atmosphere The code that should be used when transfering this Exception over an Atmosphere channel
     * @param xmpp The code that should be used when transfering this Exception over an XMPP channel
     */
    public Transformer(RealtimeExceptionCodes origin, RealtimeExceptionCodes atmosphere, RealtimeExceptionCodes xmpp) {
        this.origin = origin;
        this.atmosphere = atmosphere;
        this.xmpp = xmpp;
    }
    
    /**
     * Get the XMPP specific exception code that corresponds to this RealtimeExceptionCode
     * @return the XMPP specific exception code that corresponds to this RealtimeExceptionCode
     */
    public RealtimeExceptionCodes getXMPP() {
        return xmpp;
    }
    
    /**
     * Get the Atmosphere specific exception code that corresponds to this RealtimeExceptionCode
     * @return the Atmosphere specific exception code that corresponds to this RealtimeExceptionCode
     */
    public RealtimeExceptionCodes getAtmosphere() {
        return atmosphere;
    }
}

==> open-xchange-realtime-core_7.4.1.orig.tar.bz2: open-xchange-realtime-core-7.4.1/com.openexchange.realtime/src/com/openexchange/realtime/exception/Transformer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.exception;

import java.io.Serializable;

/**
 * {@link Transformer} used to map RealtimException codes to codes that can be used for specific {@link Channel} implementations like
 * Atmosphere or Realtime.
 * 
 * @author <a href="mailto:martin.herfurth@open-xchange.com">Martin Herfurth</a>
 * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
 */
public class Transformer implements Serializable {

    private final RealtimeExceptionCodes origin;
    private final RealtimeExceptionCodes atmosphere;
    private final RealtimeExceptionCodes xmpp;

    /**
     * Initializes a new {@link Transformer}.
     * 
     * @param origin The original ExceptionCode
     * @param atmosphere The code that should be used when transfering this Exception over an Atmosphere channel
     * @param xmpp The code that should be used when transfering this Exception over an XMPP channel
     */
    public Transformer(RealtimeExceptionCodes origin, RealtimeExceptionCodes atmosphere, RealtimeExceptionCodes xmpp) {
        this.origin = origin;
        this.atmosphere = atmosphere;
        this.xmpp = xmpp;
    }
    
    /**
     * Get the XMPP specific exception code that corresponds to this RealtimeExceptionCode
     * @return the XMPP specific exception code that corresponds to this RealtimeExceptionCode
     */
    public RealtimeExceptionCodes getXMPP() {
        return xmpp;
    }
    
    /**
     * Get the Atmosphere specific exception code that corresponds to this RealtimeExceptionCode
     * @return the Atmosphere specific exception code that corresponds to this RealtimeExceptionCode
     */
    public RealtimeExceptionCodes getAtmosphere() {
        return atmosphere;
    }
}
